/**
 * Objects for answers of fill-in-the-blank problems
 * for IQP JP 1102 at WPI
 * @author mqq
 */
package logic;

public class AnswerStruct {
	
	/** "String" 		for worded
	 * 	"Numerical" 	for number
	 * 	"Expression"	for mathematical expression
	 */
	private String type;
	
	/** Answers are stored as a string even for a numerical answer */
	private String answer;
	
	/**
	 * Tolerance for a numerical answer
	 * Case sensitivity for a worded answer:
	 * 		0: case insensitive (default)
	 * 		1: case sensitive
	 * 		Any non-zero number also stands for case sensitive
	 */
	private double tolerance; // use as tolerance for a number
							  // when used with string
							  // 0 stands for case insensitive (default)
							  // any non-zero number stands for case sensitive
	
	/**
	 * Get the tolerance of the answer
	 * @return  The tolerance of the answer
	 */
	public double getTolerance() {
		return tolerance;
	}
	
	/**
	 * Set the tolerance of the answer
	 * @param tolerance  The new tolerance
	 */
	public void setTolerance(double tolerance) {
		this.tolerance = tolerance;
	}
	
	/**
	 * Get the type of the answer
	 * @return  The type of the answer
	 */
	public String getType() {
		return type;
	}
	
	/**
	 * Set the type of the answer
	 * @param type  The new type
	 */
	public void setType(String type) {
		this.type = type;
	}
	
	/**
	 * Get the body of the answer
	 * @return  The body of the answer
	 */
	public String getAnswer() {
		return answer;
	}
	
	/**
	 * Set the body of the answer
	 * @param body  The new body
	 */
	public void setAnswer(String answer) {
		this.answer = answer;
	}
	
	public AnswerStruct (String type, String answer, double tolerance) {
		this.type = type;
		this.answer = answer;
		this.tolerance = tolerance;
	}
	
	public String toString() {
		return "ANS:  " + this.answer + "    TYPE:   " + this.type + "    TOL:   " + this.tolerance;
	}
}
