/**
 * Objects for matching problems
 * for IQP JP 1102 at WPI
 * @author mqq
 */
package logic;
import java.util.LinkedList;
import java.util.List;

public class MatchingProblem extends HwkProblem {
	/** 
	 * The matching pairs are kept in one string
	 */
	private List<String> qas = new LinkedList<String>();
	
	/**
	 * Used when check if the problem is valid
	 */
	private int numOfQas;
	
	/**
	 * Set up the problem before exporting the file
	 * For now, gives the name of the template;
	 * can be used for other things in the future
	 */
	protected void setUpProblem () {
		this.template = "matching_template_v3.txt";
	}
	
	/**
	 * Set the qas of the problem
	 * @param qas  The new qas
	 */
	public void setQas(List<String> qas) {
		this.qas = qas;
		this.numOfQas = qas.size() / 2;
	}
        
        public List<String> getQas(){
            return qas;
        }
	
	/**
	 * Add a new question and a new answer to the list
	 * @param q  The new question 
	 * @param a  The new answer
	 */
	public void addQa(String q, String a) {
		this.qas.add(q);
		this.qas.add(a);
		this.numOfQas++;
	}
	
	/**
	 * Remove a pair of qa from the list
	 * @param q  The question
	 * @param a  The answer
	 */
	public void removeQa(String q, String a) {
		this.qas.remove(q);
		this.qas.remove(a);
		this.numOfQas--;
	}
	
	/**
	 * Check if the problem is valid
	 * For matching, check if the size of the list is twice the size of the list 
	 * the number of answers qa pairs 
	 */
	protected boolean isValid() {
		return numOfQas * 2 == qas.size() && numOfQas >= 2;
	}
	
	/**
	 * Read from the template and embed the information
	 * @param input  The string from buffer
	 * @return  Modified string with information embedded
	 */
	protected String replaceTextSpecial(String input) {
		String qasString = ProblemFactory.listToString(qas);
		input = input.replace("@QaS", qasString);
		input = input.replace("@SelecteD", numOfQas+"");
		return input;
	}
	
	/**
	 * Import from a string
	 * For matching, set up the list of qas
	 */
	protected void importFromLineSpecial(String line) {
		if (this.importingMode == 3) {
			this.setQas(ProblemFactory.stringToList(line));
			this.importingMode = 0;
		}
		if (line.contains("$ml -> qa (")) {
			this.importingMode = 3;
		}
	}
	
	/**
	 * Fix problems that could occur during importing
	 */
	protected void adjust() {
		this.body = this.body.replace("\n$PAR\n\n\\{begintable(2)\\}\n\\{row(protect_enumerated_lists( $ml->print_q, $ml -> print_a) )\\}\n\\{endtable()\\}\n$PAR\n", "");
		this.body = this.body.substring(0, this.body.length() - 1);
		if (this.solution != null) {
			this.solution = this.solution.substring(3);
			this.solution = this.solution.substring(0, this.solution.length() - 1);
		}
	}
	/*public static void main(String[] args) throws IOException {
		MatchingProblem mp = new MatchingProblem();
		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		System.out.println("Please enter the header:");
		mp.setHeader(in.readLine());
		System.out.println("Please enter the problem:");
		mp.setBody(in.readLine());
		System.out.println("Please enter the qas (this test only supports 4):");
		mp.addQa(in.readLine(), in.readLine());
		mp.addQa(in.readLine(), in.readLine());
		mp.addQa(in.readLine(), in.readLine());
		mp.addQa(in.readLine(), in.readLine());
		System.out.println("Please enter the file name:");
		mp.exportFile(in.readLine());
	}*/
}
