/**
 * class to hold the static functions of this project
 * @author mqq
 */
package logic;
import java.util.LinkedList;
import java.util.List;

public class ProblemFactory {
	
	/**
	 * convert a list of string to a string that is suitable in PG
	 * In this form: "Choice1", "Choice2", ... "ChoiceN", 
	 * @param l  The list of string to be converted
	 * @return  The generated string
	 */
	public static String listToString (List<String> l) {
		String output = "";
		int n = l.size();
	    int i; // counter
	    String s_i;
	    for (i = 0; i < n; i++) {
	    	s_i = ProblemFactory.substituteEscapingCharactersQuote(l.get(i));
	    	output = output + "\"" + s_i + "\", ";
	    }
	    return output;
	}
	
	/**
	 * convert a list of string to a string that is suitable in PG
	 * In this form: "Choice1", "Choice2", ... "ChoiceN", 
	 * @param l  The list of string to be converted
	 * @return  The generated string
	 */
	public static List<String> stringToList (String input) {
		List<String> l = new LinkedList<String>();
		input = input.replace("~~\"", "QuO");
		int a;
		int b;
		while (input.contains("\"")) {
			a = input.indexOf("\"");
			input = input.substring(a + 1);
			b = input.indexOf("\"");
			l.add(ProblemFactory.substituteEscapingCharactersQuoteBack(input.substring(0, b).replace("QuO", "\"")));
			input = input.substring(b + 1);
		}
		return l;
	}
	
	/**
	 * Extract a string between two certain strings
	 * @param input  The string to be extracted from
	 * @param start  The left bound
	 * @param end  The right bound
	 * @return  The string in between
	 */
	public static String extractBetween(String input, String start, String end) {
		int a = input.indexOf(start);
		int b = input.indexOf(end);
		return input.substring(a + start.length(), b);
	}
	
	
	/**
	 * Take care of the special characters within quotation marks
	 * PG has a escaping character of ~~
	 * @param s  The string to be fixed
	 * @return  The fixed string
	 */
	public static String substituteEscapingCharactersQuote(String s) {
		s = s.replace("$", "~~$");
		s = s.replace("@", "~~@");
		s = s.replace("\"", "~~\"");
		return s;
	}
	
	/**
	 * Translate it back. Used when importing.
	 * PG has a escaping character of ~~
	 * @param s  The string to be fixed
	 * @return  The fixed string
	 */
	public static String substituteEscapingCharactersQuoteBack(String s) {
		s = s.replace("~~$", "$");
		s = s.replace("~~@", "@");
		s = s.replace("~~\"", "\"");
		return s;
	}
	
	/**
	 * Take care of the special characters in the text section
	 * PG has a escaping character of ~~
	 * @param s  The string to be fixed
	 * @return  The fixed string
	 */
	public static String substituteEscapingCharactersText(String s) {
		s = s.replace("$", "~~$");
		s = s.replace("@", "~~@");
		s = s.replace("\n", "$BR\n");
		s = s.replace("\r", "$BR\r");
		return s;
	}
	
	/**
	 * Translate it back. Used when importing.
	 * PG has a escaping character of ~~
	 * @param s  The string to be fixed
	 * @return  The fixed string
	 */
	public static String substituteEscapingCharactersTextBack(String s) {
		s = s.replace("~~$", "$");
		s = s.replace("~~@", "@");
		s = s.replace("$BR", "");
		return s;
	}
}
